Shiv API
========

.. automodule:: shiv
    :members:
    :show-inheritance:

cli
---

.. automodule:: shiv.cli
    :members:
    :show-inheritance:

constants
---

.. automodule:: shiv.constants
    :members:
    :show-inheritance:

builder
-------

.. automodule:: shiv.builder
    :members:
    :show-inheritance:

pip
---

.. automodule:: shiv.pip
    :members:
    :show-inheritance:

bootstrap
---------

.. automodule:: shiv.bootstrap
    :members:
    :show-inheritance:

bootstrap.environment
---------------------

.. automodule:: shiv.bootstrap.environment
    :members:
    :show-inheritance:

bootstrap.interpreter
---------------------

.. automodule:: shiv.bootstrap.interpreter
    :members:
    :show-inheritance:
